@@ -14,32 +14,51 @@ and so can be used in most places where a normal array would be used, including
 
 # Constructors
 
+You can create a `QuantityArray` by multiplying an array with a `Quantity`:
+
+```julia
+x = (0:0.1:10)u"km/s"
+```
+
+Alternatively, the following constructors are available:
+
 - `QuantityArray(v::AbstractArray, d::AbstractDimensions)`: Create a `QuantityArray` with value `v` and dimensions `d`,
   using `Quantity` if the eltype of `v` is numeric, and `GenericQuantity` otherwise.
+
 - `QuantityArray(v::AbstractArray{<:Number}, q::AbstractQuantity)`: Create a `QuantityArray` with value `v` and dimensions inferred
-   with `dimension(q)`. This is so that you can easily create an array with the units module, like so:
-   ```julia
-   julia> A = QuantityArray(randn(32), 1u"m")
-   ```
+  with `dimension(q)`. This is so that you can easily create an array with the units module, like so:
+
+  ```julia
+  A = QuantityArray(randn(32), 1u"m")
+  ```
+
 - `QuantityArray(v::AbstractArray{<:Any}, q::AbstractGenericQuantity)`: Create a `QuantityArray` with
-    value `v` and dimensions inferred with `dimension(q)`.
-    This is so that you can easily create quantity arrays of non-numeric eltypes, like so:
-   ```julia
-   julia> A = QuantityArray([[1.0], [2.0, 3.0]], GenericQuantity(1u"m"))
-   ```
+  value `v` and dimensions inferred with `dimension(q)`.
+  This is so that you can easily create quantity arrays of non-numeric eltypes, like so:
+
+  ```julia
+  A = QuantityArray([[1.0], [2.0, 3.0]], GenericQuantity(1u"m"))
+  ```
+
 - `QuantityArray(v::AbstractArray{<:UnionAbstractQuantity})`: Create a `QuantityArray` from an array of quantities. This means the following
   syntax works:
+
   ```julia
-  julia> A = QuantityArray(randn(32) .* 1u"km/s")
+  A = QuantityArray(randn(32) .* 1u"km/s")
   ```
+
 - `QuantityArray(v::AbstractArray; kws...)`: Create a `QuantityArray` with dimensions inferred from the keyword arguments. For example:
+
   ```julia
-  julia> A = QuantityArray(randn(32); length=1)
+  A = QuantityArray(randn(32); length=1)
   ```
+
   is equivalent to
+
   ```julia
-  julia> A = QuantityArray(randn(32), u"m")
+  A = QuantityArray(randn(32), u"m")
   ```
+
   The keyword arguments are passed to `DEFAULT_DIM_TYPE`.
 """
 struct QuantityArray{T,N,D<:AbstractDimensions,Q<:UnionAbstractQuantity{T,D},V<:AbstractArray{T,N}} <: AbstractArray{Q,N}
@@ -60,6 +79,20 @@ for (type, base_type, default_type) in ABSTRACT_QUANTITY_TYPES
     if type in (AbstractQuantity, AbstractGenericQuantity)
         @eval QuantityArray(v::AbstractArray{<:$base_type}, d::AbstractDimensions) = QuantityArray(v, d, $default_type)
     end
+
+    @eval begin
+        Base.:*(A::AbstractArray{T}, q::$type) where {T<:Number} = QuantityArray(A, q)
+        Base.:*(q::$type, A::AbstractArray{T}) where {T<:Number} = A * q
+        Base.:/(A::AbstractArray{T}, q::$type) where {T<:Number} = A * inv(q)
+    end
+
+    for (type2, _, _) in ABSTRACT_QUANTITY_TYPES
+        @eval begin
+            Base.:*(A::AbstractArray{<:$type2}, q::$type) = A .* q
+            Base.:*(q::$type, A::AbstractArray{<:$type2}) = q .* A
+            Base.:/(A::AbstractArray{<:$type2}, q::$type) = A ./ q
+        end
+    end
 end
 QuantityArray(v::QA) where {Q<:UnionAbstractQuantity,QA<:AbstractArray{Q}} =
     let
@@ -480,7 +513,7 @@ end
         for dim1 in ((3,), (3, 3)), dim2 in ((3,), (3, 3))
             A = QuantityArray(rand(T, dim1...), Q{T}(u"m"))
             B = QuantityArray(rand(T, dim2...), Q{T}(u"s^2"))
-            
+
             if dim1 == (3,) && dim2 == (3,)
                 @test ustrip(A / B) ≈ ustrip(A) / ustrip(B)
                 @test dimension(A / B) == dimension(A) / dimension(B)
